From a56b1c5e3a78eda110227cced6d741ddbde494f5 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Judy=28=E1=84=87=E1=85=A2=E1=86=A8=E1=84=8C=E1=85=AE?=
=?UTF-8?q?=E1=84=8B=E1=85=A7=E1=86=BC=29?=
<141113236+juyeong-baek@users.noreply.github.com>
Date: Mon, 1 Apr 2024 10:28:07 +0900
Subject: [PATCH 1/2] =?UTF-8?q?fix:=20georeferencing=EC=9D=84=20=EC=82=AC?=
=?UTF-8?q?=EC=9A=A9=ED=95=98=EC=A7=80=20=EC=95=8A=EC=9D=84=20=EB=95=8C=20?=
=?UTF-8?q?changeFloor=20=EC=97=90=20=EB=8C=80=ED=95=9C=20=EC=84=A4?=
=?UTF-8?q?=EB=AA=85=EC=B6=94=EA=B0=80?=
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
---
src/components/pages/multiMap/multiMapText.jsx | 9 ++++++---
src/components/pages/multiMap/multiMapTextEn.jsx | 14 ++++++++------
2 files changed, 14 insertions(+), 9 deletions(-)
diff --git a/src/components/pages/multiMap/multiMapText.jsx b/src/components/pages/multiMap/multiMapText.jsx
index b66d194..be4a3fd 100644
--- a/src/components/pages/multiMap/multiMapText.jsx
+++ b/src/components/pages/multiMap/multiMapText.jsx
@@ -55,9 +55,11 @@ map.context.removeBuilding(buildingId); // 4. 그렸던 빌딩 제거
1.2. floor 를 입력하지 않으면 실외지도가 가장 먼저 그려지게 됩니다.
- 2. 빌딩 혹은 실외지도를 switching하기 위해 addBuilding 을 통해 원하는 빌딩, 층으로 이동할 수 있습니다.
+ 2. 빌딩 혹은 실외지도를 switching하기 위해 addBuilding 혹은 changeFloor 을 통해 원하는 빌딩, 층으로 이동할 수 있습니다.
- 2.1. 빌딩 혹은 실외지도로 이동하게 되면 기존에 그려져있던 빌딩 혹은 실외지도는 지워집니다.
+ 2.1. changeFloor() 를 통해 다른 빌딩의 층으로도 이동할 수 있습니다.
+
+ 2.2. 빌딩 혹은 실외지도로 이동하게 되면 기존에 그려져있던 빌딩 혹은 실외지도는 지워집니다.
{`
@@ -66,7 +68,8 @@ const mapOption = {
}
// 실외지도가 있는 지도에서 floor 를 입력하지 않으면 기본층은 실외지도로 가장 먼저 실외지도가 그려지게 됩니다.
const map = await dabeeoMaps.showMap(mapContainer, mapOption, mapData); // 1. 1번 빌딩 1층 표출
-await map.context.addBuilding(buildingId, floorId); // 2. 다른 층 표출 (1번 빌딩 제거)
+await map.context.addBuilding(buildingId, floorId); // 2. 다른 빌딩의 다른 층 표출 (1번 빌딩 제거)
+await map.context.changeFloor(floorId) // 3. 다른 층으로 이동 (다른 빌딩의 층으로도 가능)
`}
From 0497c8350b95d5ab00362669917b57c46cd9e64c Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Judy=28=E1=84=87=E1=85=A2=E1=86=A8=E1=84=8C=E1=85=AE?=
=?UTF-8?q?=E1=84=8B=E1=85=A7=E1=86=BC=29?=
<141113236+juyeong-baek@users.noreply.github.com>
Date: Mon, 1 Apr 2024 10:44:25 +0900
Subject: [PATCH 2/2] =?UTF-8?q?fix:=20changeFloor()=20=EC=84=A4=EB=AA=85?=
=?UTF-8?q?=20=EC=88=98=EC=A0=95?=
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
---
src/components/pages/multiMap/multiMapText.jsx | 12 +++++++-----
src/components/pages/multiMap/multiMapTextEn.jsx | 8 +++++---
2 files changed, 12 insertions(+), 8 deletions(-)
diff --git a/src/components/pages/multiMap/multiMapText.jsx b/src/components/pages/multiMap/multiMapText.jsx
index be4a3fd..341cbc4 100644
--- a/src/components/pages/multiMap/multiMapText.jsx
+++ b/src/components/pages/multiMap/multiMapText.jsx
@@ -55,11 +55,13 @@ map.context.removeBuilding(buildingId); // 4. 그렸던 빌딩 제거
1.2. floor 를 입력하지 않으면 실외지도가 가장 먼저 그려지게 됩니다.
- 2. 빌딩 혹은 실외지도를 switching하기 위해 addBuilding 혹은 changeFloor 을 통해 원하는 빌딩, 층으로 이동할 수 있습니다.
+ 2. 빌딩 혹은 실외지도를 switching하기 위해 addBuilding 혹은 changeFloor 을 통해 원하는 빌딩, 층으로 이동할 수 있습니다.
- 2.1. changeFloor() 를 통해 다른 빌딩의 층으로도 이동할 수 있습니다.
+ 2.1. addBuilding(buildingId, floorId) 으로 이동하는 경우는 특정 빌딩의 특정 층으로 이동할 수 있습니다.
- 2.2. 빌딩 혹은 실외지도로 이동하게 되면 기존에 그려져있던 빌딩 혹은 실외지도는 지워집니다.
+ 2.2. addBuilding() 을 사용하지 않고 changeFloor() 를 통해 다른 빌딩의 층으로도 이동할 수 있습니다.
+
+ 2.3. 빌딩 혹은 실외지도로 이동하게 되면 기존에 그려져있던 빌딩 혹은 실외지도는 지워집니다.
{`
@@ -68,8 +70,8 @@ const mapOption = {
}
// 실외지도가 있는 지도에서 floor 를 입력하지 않으면 기본층은 실외지도로 가장 먼저 실외지도가 그려지게 됩니다.
const map = await dabeeoMaps.showMap(mapContainer, mapOption, mapData); // 1. 1번 빌딩 1층 표출
-await map.context.addBuilding(buildingId, floorId); // 2. 다른 빌딩의 다른 층 표출 (1번 빌딩 제거)
-await map.context.changeFloor(floorId) // 3. 다른 층으로 이동 (다른 빌딩의 층으로도 가능)
+await map.context.addBuilding(buildingId, floorId); // 2.1. 다른 빌딩의 다른 층 표출 (1번 빌딩 제거)
+await map.context.changeFloor(floorId) // 2.2. 다른 층으로 이동 (다른 빌딩의 층으로도 가능)
`}
diff --git a/src/components/pages/multiMap/multiMapTextEn.jsx b/src/components/pages/multiMap/multiMapTextEn.jsx
index f06935a..8067063 100644
--- a/src/components/pages/multiMap/multiMapTextEn.jsx
+++ b/src/components/pages/multiMap/multiMapTextEn.jsx
@@ -53,11 +53,13 @@ map.context.removeBuilding(buildingId); // 4. Remove the drawn building
1.2. If no floor is specified, the outdoor map will be drawn first.
- 2. To switch between buildings or outdoor maps, you can move to the desired building or floor using addBuilding or changeFloor.
+ 2. To switch between buildings or outdoor maps, you can move to the desired building or floor using addBuilding or changeFloor.
- 2.1. You can also move to floors of different buildings using changeFloor().
+ 2.1. When using addBuilding(buildingId, floorId), you can move to a specific floor of a specific building.
- 2.2. When moving to a building or outdoor map, the previously drawn building or outdoor map will be cleared.
+ 2.2. Without using addBuilding(), you can also move to floors of different buildings using changeFloor().
+
+ 2.3. When moving to a building or outdoor map, the previously drawn building or outdoor map will be cleared.
{`
diff --git a/src/components/pages/multiMap/multiMapTextEn.jsx b/src/components/pages/multiMap/multiMapTextEn.jsx
index ad349b0..f06935a 100644
--- a/src/components/pages/multiMap/multiMapTextEn.jsx
+++ b/src/components/pages/multiMap/multiMapTextEn.jsx
@@ -53,19 +53,21 @@ map.context.removeBuilding(buildingId); // 4. Remove the drawn building
1.2. If no floor is specified, the outdoor map will be drawn first.
- 2. Use addBuilding to switch between buildings or outdoor maps.
+ 2. To switch between buildings or outdoor maps, you can move to the desired building or floor using addBuilding or changeFloor.
- 2.1. When moving to a building or outdoor map, the previously drawn building or outdoor map will be removed.
+ 2.1. You can also move to floors of different buildings using changeFloor().
+
+ 2.2. When moving to a building or outdoor map, the previously drawn building or outdoor map will be cleared.
{`
const mapOption = {
floor: building1_floor1_id,
-};
-
-// When "floor" is not entered, the default floor is the outdoor map, which is drawn first.
+}
+// If you do not specify the floor when there is an outdoor map, the default floor will be the outdoor map, which will be drawn first.
const map = await dabeeoMaps.showMap(mapContainer, mapOption, mapData); // 1. Displaying Building 1, Floor 1
-await map.context.addBuilding(buildingId, floorId); // 2. Displaying another floor (Removing Building 1)
+await map.context.addBuilding(buildingId, floorId); // 2. Displaying a Different Floor of a Different Building (Removing Building 1)
+await map.context.changeFloor(floorId) // 3. Moving to a Different Floor (Also Possible to Move to a Floor of a Different Building)
`}